function [msd_time, msd_mean, msd_p] = computeMSD(X,Y)
% this function computes mean square displacement in 2D
% for a given ensemble (group) of particles
%
% function assumes X and Y are matrices with format/dimesnions:
% rows are time_steps
% columns are [time particle_1 particle_2 ... particle_end]
%
% DAP 12/30/2017

msd=zeros(size(X,1),size(X,2)-1);

r0 = sqrt(X(1,2:22).^2+Y(1,2:22).^2);

t_end = size(X,1);
p_end = size(X,2)-1;

for particle = 2:p_end % for every particle...
    msd_t = 0;
    for t = 1:t_end % for each simulation time step
        r_T = sqrt(X(t,particle)^2+Y(t,particle)^2);
        msd_t = (r_T-r0(particle-1))^2;
        % this looks much better...
        msd(t,particle) = msd_t;
    end
end

msd_time = X(:,1);
msd_mean = mean(msd,2);
msd_p = msd;